@@ -6,7 +6,6 @@ PREFIX=/Users/darco/Projects/Voria/synfig-build
 
 export PKG_CONFIG_PATH=$PREFIX/lib/pkgconfig:/usr/lib/pkgconfig:/usr/X11R6/lib/pkgconfig
 OPTIONS="--prefix=$PREFIX"
-#OPTIONS="$OPTIONS --enable-timelimit=120"
 #OPTIONS="$OPTIONS --enable-optimization=2"
 OPTIONS="$OPTIONS --enable-optimization=3"
 #OPTIONS="$OPTIONS --enable-g5opt"
@@ -38,7 +37,7 @@ CXXCPP="g++ -E"
 
 BUILDDIR=macosxbuild
 
-[ -e configure ] || ./bootstrap || exit 1
+[ -e configure ] || ( libtoolize --ltdl --copy --force && autoreconf --force --install ) || exit 1
 
 [ -d $BUILDDIR ] && rm -fr $BUILDDIR
 
