@@ -102,11 +102,11 @@ Layer_Freetype::Layer_Freetype()
 	param_vcompress=ValueBase(Real(1.0));
 	param_weight=ValueBase(WEIGHT_NORMAL);
 	param_style=ValueBase(PANGO_STYLE_NORMAL);
-	param_family=ValueBase("Sans Serif");
+	param_family=ValueBase((const char*)"Sans Serif");
 	param_use_kerning=ValueBase(true);
 	param_grid_fit=ValueBase(false);
 	param_invert=ValueBase(false);
-	param_font=ValueBase("");
+	param_font=ValueBase(synfig::String());
 
 	old_version=false;
 
@@ -408,7 +408,7 @@ Layer_Freetype::new_face(const String &newfont)
 				FcFontSetAdd(fs, match);
 			if (pat)
 				FcPatternDestroy(pat);
-			if(fs){
+			if(fs && fs->nfont){
 				FcChar8* file;
 				if( FcPatternGetString (fs->fonts[0], FC_FILE, 0, &file) == FcResultMatch )
 					error=FT_New_Face(ft_library,(const char*)file,face_index,&face);
@@ -687,6 +687,8 @@ Layer_Freetype::get_color(Context context, const synfig::Point &pos)const
 bool
 Layer_Freetype::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
 {
+	RENDER_TRANSFORMED_IF_NEED(__FILE__, __LINE__)
+
 	bool use_kerning=param_use_kerning.get(bool());
 	bool grid_fit=param_grid_fit.get(bool());
 	bool invert=param_invert.get(bool());
@@ -1081,7 +1083,7 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 	// Vertical
 	int total_lines=pango_layout_get_line_count(layout);
 	float vspace_total=vcompress>1.0?0.4*logical_layout.height*(vcompress-1.0):(vcompress<1.0)?0.6*logical_layout.height*(vcompress-1.0):0;
-	float vspace;
+	float vspace=0;
 	if(total_lines>1)
 		vspace=vspace_total/(total_lines-1);
 	pango_layout_set_spacing(layout, vspace*PANGO_SCALE);
