@@ -150,7 +150,7 @@ find_closest_to_bline(bool fast, const std::vector<synfig::BLinePoint>& bline,co
 inline void
 CurveWarp::sync()
 {
-	std::vector<synfig::BLinePoint> bline(param_bline.get_list().begin(),param_bline.get_list().end());
+	std::vector<synfig::BLinePoint> bline(param_bline.get_list_of(synfig::BLinePoint()));
 	Point start_point=param_start_point.get(Point());
 	Point end_point=param_end_point.get(Point());
 	
@@ -175,7 +175,7 @@ CurveWarp::CurveWarp():
 	bline[1].set_tangent(Point(1, -0.1));
 	bline[0].set_width(1.0f);
 	bline[1].set_width(1.0f);
-	param_bline.set(bline);
+	param_bline.set_list_of(bline);
 	sync();
 
 	SET_INTERPOLATION_DEFAULTS();
@@ -185,7 +185,7 @@ CurveWarp::CurveWarp():
 inline Point
 CurveWarp::transform(const Point &point_, Real *dist, Real *along, int quality)const
 {
-	std::vector<synfig::BLinePoint> bline(param_bline.get_list().begin(),param_bline.get_list().end());
+	std::vector<synfig::BLinePoint> bline(param_bline.get_list_of(synfig::BLinePoint()));
 	Point start_point=param_start_point.get(Point());
 	Point end_point=param_end_point.get(Point());
 	Point origin=param_origin.get(Point());
@@ -254,7 +254,7 @@ CurveWarp::transform(const Point &point_, Real *dist, Real *along, int quality)c
 
 			if (t<0.5)
 			{
-				if (iter->get_split_tangent_flag() || zero_tangent)
+				if (iter->get_split_tangent_angle() || iter->get_split_tangent_radius() || zero_tangent)
 				{
 					// fake the current tangent if we need to
 					if (zero_tangent) tangent = curve(FAKE_TANGENT_STEP) - curve(0);
@@ -279,7 +279,7 @@ CurveWarp::transform(const Point &point_, Real *dist, Real *along, int quality)c
 			}
 			else
 			{
-				if (next->get_split_tangent_flag() || zero_tangent)
+				if (next->get_split_tangent_angle() || next->get_split_tangent_radius() || zero_tangent)
 				{
 					// fake the current tangent if we need to
 					if (zero_tangent) tangent = curve(1) - curve(1-FAKE_TANGENT_STEP);
@@ -434,6 +434,8 @@ CurveWarp::get_color(Context context, const Point &point)const
 bool
 CurveWarp::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
 {
+	RENDER_TRANSFORMED_IF_NEED(__FILE__, __LINE__)
+
 	Point start_point=param_start_point.get(Point());
 	Point end_point=param_end_point.get(Point());
 
