@@ -43,6 +43,7 @@
 #include <synfig/value.h>
 #include <synfig/valuenode.h>
 #include <synfig/canvas.h>
+#include <synfig/filesystemnative.h>
 
 #endif
 
@@ -88,9 +89,10 @@ Import::set_param(const String & param, const ValueBase &value)
 {
 	try{
 	IMPORT_VALUE(param_time_offset);
-IMPORT_VALUE_PLUS(param_filename,
+
+	String filename=param_filename.get(String());
+	IMPORT_VALUE_PLUS_BEGIN(param_filename)
 	{
-		String filename=param_filename.get(String());
 		if(!get_canvas())
 		{
 			filename=value.get(filename);
@@ -129,6 +131,11 @@ IMPORT_VALUE_PLUS(param_filename,
 		}
 #endif
 
+		// TODO: "images" and "container:" literals
+		String newfilename_orig = newfilename;
+		if (newfilename_orig.substr(0, String("#").size()) == "#")
+			newfilename_orig = "#images/" + newfilename_orig.substr(String("#").size());
+
 		if(filename.empty())
 			filename=newfilename;
 
@@ -157,24 +164,29 @@ IMPORT_VALUE_PLUS(param_filename,
 
 				assert(get_canvas());
 
-				if(is_absolute_path(newfilename))
-					filename_with_path=newfilename;
+				FileSystem::Handle file_system = get_canvas()->get_identifier().file_system;
+				if (!file_system) file_system = FileSystemNative::instance();
+
+				// todo: literal "container:"
+				if(is_absolute_path(newfilename_orig)
+				|| newfilename_orig.substr(0, std::string("#").size())=="#")
+					filename_with_path=newfilename_orig;
 				else
-					filename_with_path=get_canvas()->get_file_path()+ETL_DIRECTORY_SEPARATOR+newfilename;
+					filename_with_path=absolute_path(get_canvas()->get_file_path()+ETL_DIRECTORY_SEPARATOR+newfilename_orig);
 
 				handle<Importer> newimporter;
 
-				newimporter=Importer::open(absolute_path(filename_with_path));
+				newimporter=Importer::open(file_system->get_identifier(filename_with_path));
 
 				if(!newimporter)
 				{
-					newimporter=Importer::open(get_canvas()->get_file_path()+ETL_DIRECTORY_SEPARATOR+basename(newfilename));
+					newimporter=Importer::open(file_system->get_identifier(get_canvas()->get_file_path()+ETL_DIRECTORY_SEPARATOR+basename(newfilename_orig)));
 					if(!newimporter)
 					{
 						synfig::error(strprintf("Unable to create an importer object with file \"%s\"",filename_with_path.c_str()));
 						importer=0;
 						filename=newfilename;
-						abs_filename=absolute_path(filename_with_path);
+						abs_filename=filename_with_path;
 						surface.clear();
 						param_filename.set(filename);
 						return false;
@@ -189,7 +201,7 @@ IMPORT_VALUE_PLUS(param_filename,
 
 				importer=newimporter;
 				filename=newfilename;
-				abs_filename=absolute_path(filename_with_path);
+				abs_filename=filename_with_path;
 				param_filename.set(filename);
 
 				return true;
@@ -206,52 +218,57 @@ IMPORT_VALUE_PLUS(param_filename,
 					synfig::warning(strprintf(_("Filename seems to already be set to \"%s\" (%s)"),filename.c_str(),newfilename.c_str()));
 					return true;
 				}
-				 assert(get_canvas());
+				assert(get_canvas());
 				 
-				 if(is_absolute_path(newfilename))
-					 filename_with_path=newfilename;
-				 else
-					 filename_with_path=get_canvas()->get_file_path()+ETL_DIRECTORY_SEPARATOR+newfilename;
+				FileSystem::Handle file_system = get_canvas()->get_identifier().file_system;
+				if (!file_system) file_system = FileSystemNative::instance();
+
+				// todo: literal "container:"
+				if(is_absolute_path(newfilename_orig)
+				|| newfilename_orig.substr(0, std::string("#").size())=="#")
+					filename_with_path=newfilename_orig;
+				else
+					filename_with_path=absolute_path(get_canvas()->get_file_path()+ETL_DIRECTORY_SEPARATOR+newfilename_orig);
 				 
-				 handle<CairoImporter> newimporter;
+				handle<CairoImporter> newimporter;
 				 
-				 newimporter=CairoImporter::open(absolute_path(filename_with_path));
+				newimporter=CairoImporter::open(file_system->get_identifier(filename_with_path));
 				 
-				 if(!newimporter)
-				 {
-					 newimporter=CairoImporter::open(get_canvas()->get_file_path()+ETL_DIRECTORY_SEPARATOR+basename(newfilename));
-					 if(!newimporter)
-					 {
-						 synfig::error(strprintf("Unable to create an importer object with file \"%s\"",filename_with_path.c_str()));
-						 cimporter=0;
-						 filename=newfilename;
-						 abs_filename=absolute_path(filename_with_path);
-						 csurface.set_cairo_surface(NULL);
-						 param_filename.set(filename);
-						 return false;
-					 }
-				 }
+				if(!newimporter)
+				{
+					newimporter=CairoImporter::open(file_system->get_identifier(get_canvas()->get_file_path()+ETL_DIRECTORY_SEPARATOR+basename(newfilename_orig)));
+					if(!newimporter)
+					{
+						synfig::error(strprintf("Unable to create an importer object with file \"%s\"",filename_with_path.c_str()));
+						cimporter=0;
+						filename=newfilename;
+						abs_filename=filename_with_path;
+						csurface.set_cairo_surface(NULL);
+						param_filename.set(filename);
+						return false;
+					}
+				}
 				 
-				 cairo_surface_t* cs;
-				 if(!newimporter->get_frame(cs, get_canvas()->rend_desc(), Time(0), trimmed, width, height, top, left))
-				 {
+				cairo_surface_t* cs;
+				if(!newimporter->get_frame(cs, get_canvas()->rend_desc(), Time(0), trimmed, width, height, top, left))
+				{
 					synfig::warning(strprintf("Unable to get frame from \"%s\"",filename_with_path.c_str()));
-				 }
-				 set_cairo_surface(cs);
-				 cairo_surface_destroy(cs);
+				}
+				set_cairo_surface(cs);
+				cairo_surface_destroy(cs);
 				 
-				 cimporter=newimporter;
-				 filename=newfilename;
-				 abs_filename=absolute_path(filename_with_path);
-				 param_filename.set(filename);
-				 
-				 return true;
+				cimporter=newimporter;
+				filename=newfilename;
+				abs_filename=filename_with_path;
+				param_filename.set(filename);
+
+				return true;
 				
 				//return false;
 			}
 		}
 	}
-	);
+	IMPORT_VALUE_PLUS_END
 	} catch(...) { set_amount(0); return false; }
 
 	return Layer_Bitmap::set_param(param,value);
@@ -266,12 +283,19 @@ Import::get_param(const String & param)const
 	{
 		if(param=="filename")
 		{
-			ValueBase ret(ValueBase::TYPE_STRING);
+			ValueBase ret(type_string);
 			// This line is needed to copy the internals of ValueBase from param_filename
 			ret=param_filename;
 			
-			string curpath(cleanup_path(absolute_path(get_canvas()->get_file_path())));
-			ret=relative_path(curpath,abs_filename);
+			// todo: literal "container:" and "images"
+			if(ret.get(String()).substr(0, std::string("#").size())!="#") {
+				string curpath(cleanup_path(absolute_path(get_canvas()->get_file_path())));
+				ret=relative_path(curpath,abs_filename);
+			} else
+			if(ret.get(String()).substr(0, std::string("#images/").size())=="#images/") {
+				ret = "#" + ret.get(String()).substr(std::string("#images/").size());
+			}
+
 			return ret;
 		}
 	}
