@@ -160,7 +160,7 @@ InsideOut::get_param_vocab()const
 
 	ret.push_back(ParamDesc("origin")
 		.set_local_name(_("Origin"))
-		.set_description(_("Defines the where the center will be"))
+		.set_description(_("Defines where the center will be"))
 	);
 
 	return ret;
