@@ -49,7 +49,8 @@ class Layer_Stroboscope : public Layer
 	SYNFIG_LAYER_MODULE_EXT
 
 private:
-	float	frequency;
+	//!Parameter (float)
+	ValueBase param_frequency;
 
 protected:
 	Layer_Stroboscope();
@@ -64,9 +65,9 @@ public:
 	virtual Vocab get_param_vocab()const;
 	virtual Color get_color(Context context, const Point &pos)const;
 
-	virtual void set_time(Context context, Time time)const;
+	virtual void set_time(IndependentContext context, Time time)const;
 	virtual bool accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
-	virtual bool accelerated_cairorender(Context context,cairo_surface_t *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
+	virtual bool accelerated_cairorender(Context context,cairo_t *cr, int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
 };
 /* === E N D =============================================================== */
 
