@@ -29,7 +29,7 @@
 
 /* === H E A D E R S ======================================================= */
 
-#include <synfig/layer_composite.h>
+#include <synfig/layers/layer_composite.h>
 #include <synfig/color.h>
 #include <synfig/vector.h>
 #include <synfig/value.h>
