@@ -31,7 +31,7 @@
 
 /* === H E A D E R S ======================================================= */
 
-#include <synfig/layer_composite.h>
+#include <synfig/layers/layer_composite.h>
 #include <synfig/color.h>
 #include <synfig/context.h>
 #include <synfig/vector.h>
