@@ -52,33 +52,47 @@ SYNFIG_IMPORTER_SET_NAME(bmp_mptr,"bmp");
 SYNFIG_IMPORTER_SET_EXT(bmp_mptr,"bmp");
 SYNFIG_IMPORTER_SET_VERSION(bmp_mptr,"0.1");
 SYNFIG_IMPORTER_SET_CVS_ID(bmp_mptr,"$Id$");
+SYNFIG_IMPORTER_SET_SUPPORTS_FILE_SYSTEM_WRAPPER(bmp_mptr, true);
 
 /* === M E T H O D S ======================================================= */
 namespace synfig {
 
-struct BITMAPFILEHEADER
-{
-	unsigned char	bfType[2];
-	unsigned long	bfSize;
-	unsigned short	bfReserved1;
-	unsigned short	bfReserved2;
-	unsigned long	bfOffsetBits;
-};
+#pragma pack(push, 1)
 
-struct BITMAPINFOHEADER
+namespace BITMAP
 {
-	unsigned long	biSize;
-	long			biWidth;
-	long			biHeight;
-	unsigned short	biPlanes;
-	unsigned short	biBitCount;
-	unsigned long	biCompression;
-	unsigned long	biSizeImage;
-	long			biXPelsPerMeter;
-	long			biYPelsPerMeter;
-	unsigned long	biClrUsed;
-	unsigned long	biClrImportant;
-};
+	typedef unsigned char uint8_t;
+	typedef unsigned short int uint16_t;
+	typedef int int32_t;
+	typedef unsigned int uint32_t;
+
+	struct FILEHEADER
+	{
+		uint8_t		bfType[2];
+		uint32_t	bfSize;
+		uint16_t	bfReserved1;
+		uint16_t	bfReserved2;
+		uint32_t	bfOffsetBits;
+	};
+
+	struct INFOHEADER
+	{
+		uint32_t	biSize;
+		int32_t		biWidth;
+		int32_t		biHeight;
+		uint16_t	biPlanes;
+		uint16_t	biBitCount;
+		uint32_t	biCompression;
+		uint32_t	biSizeImage;
+		int32_t		biXPelsPerMeter;
+		int32_t		biYPelsPerMeter;
+		uint32_t	biClrUsed;
+		uint32_t	biClrImportant;
+	};
+}
+
+
+#pragma pack(pop)
 
 }
 
@@ -109,53 +123,40 @@ inline short little_endian_short(const short &x)
 #endif
 
 
-
-
-
-
-bmp_mptr::bmp_mptr(const char *file)
-{
-	filename=file;
-}
-
-bmp_mptr::~bmp_mptr()
-{
-}
-
 bool
 bmp_mptr::get_frame(synfig::Surface &surface, const synfig::RendDesc &/*renddesc*/, Time /*time*/, synfig::ProgressCallback *cb)
 {
-	FILE *file=fopen(filename.c_str(),"rb");
-	if(!file)
+	FileSystem::ReadStreamHandle stream = identifier.get_read_stream();
+	if(!stream)
 	{
-		if(cb)cb->error("bmp_mptr::GetFrame(): "+strprintf(_("Unable to open %s"),filename.c_str()));
-		else synfig::error("bmp_mptr::GetFrame(): "+strprintf(_("Unable to open %s"),filename.c_str()));
+		if(cb)cb->error("bmp_mptr::GetFrame(): "+strprintf(_("Unable to open %s"),identifier.filename.c_str()));
+		else synfig::error("bmp_mptr::GetFrame(): "+strprintf(_("Unable to open %s"),identifier.filename.c_str()));
 		return false;
 	}
 
-	synfig::BITMAPFILEHEADER fileheader;
-	synfig::BITMAPINFOHEADER infoheader;
-	char b_char=fgetc(file);
-	char m_char=fgetc(file);
+	synfig::BITMAP::FILEHEADER fileheader;
+	synfig::BITMAP::INFOHEADER infoheader;
 
-	if(b_char!='B' || m_char!='M')
+	if (!stream->read_variable(fileheader.bfType)
+	 || fileheader.bfType[0] != 'B'
+	 || fileheader.bfType[1] != 'M')
 	{
-		if(cb)cb->error("bmp_mptr::GetFrame(): "+strprintf(_("%s is not in BMP format"),filename.c_str()));
-		else synfig::error("bmp_mptr::GetFrame(): "+strprintf(_("%s is not in BMP format"),filename.c_str()));
+		if(cb)cb->error("bmp_mptr::GetFrame(): "+strprintf(_("%s is not in BMP format"),identifier.filename.c_str()));
+		else synfig::error("bmp_mptr::GetFrame(): "+strprintf(_("%s is not in BMP format"),identifier.filename.c_str()));
 		return false;
 	}
 
-	if(fread(&fileheader.bfSize, 1, sizeof(synfig::BITMAPFILEHEADER)-4, file)!=sizeof(synfig::BITMAPFILEHEADER)-4)
+	if(!stream->read_whole_block(&fileheader.bfSize, sizeof(synfig::BITMAP::FILEHEADER)-2))
 	{
-		String str("bmp_mptr::get_frame(): "+strprintf(_("Failure while reading BITMAPFILEHEADER from %s"),filename.c_str()));
+		String str("bmp_mptr::get_frame(): "+strprintf(_("Failure while reading BITMAP::FILEHEADER from %s"),identifier.filename.c_str()));
 		if(cb)cb->error(str);
 		else synfig::error(str);
 		return false;
 	}
 
-	if(fread(&infoheader, 1, sizeof(synfig::BITMAPINFOHEADER), file)!=sizeof(synfig::BITMAPINFOHEADER))
+	if(!stream->read_whole_block(&infoheader, sizeof(synfig::BITMAP::INFOHEADER)))
 	{
-		String str("bmp_mptr::get_frame(): "+strprintf(_("Failure while reading BITMAPINFOHEADER from %s"),filename.c_str()));
+		String str("bmp_mptr::get_frame(): "+strprintf(_("Failure while reading BITMAP::INFOHEADER from %s"),identifier.filename.c_str()));
 		if(cb)cb->error(str);
 		else synfig::error(str);
 		return false;
@@ -163,17 +164,17 @@ bmp_mptr::get_frame(synfig::Surface &surface, const synfig::RendDesc &/*renddesc
 
 	int offset=little_endian(fileheader.bfOffsetBits);
 
-	if(offset!=sizeof(synfig::BITMAPFILEHEADER)+sizeof(synfig::BITMAPINFOHEADER)-2)
+	if(offset!=sizeof(synfig::BITMAP::FILEHEADER)+sizeof(synfig::BITMAP::INFOHEADER))
 	{
-		String str("bmp_mptr::get_frame(): "+strprintf(_("Bad BITMAPFILEHEADER in %s. (bfOffsetBits=%d, should be %d)"),filename.c_str(),offset,sizeof(synfig::BITMAPFILEHEADER)+sizeof(synfig::BITMAPINFOHEADER)-2));
+		String str("bmp_mptr::get_frame(): "+strprintf(_("Bad BITMAP::FILEHEADER in %s. (bfOffsetBits=%d, should be %d)"),identifier.filename.c_str(),offset,sizeof(synfig::BITMAP::FILEHEADER)+sizeof(synfig::BITMAP::INFOHEADER)));
 		if(cb)cb->error(str);
 		else synfig::error(str);
 		return false;
 	}
 
-	if(little_endian(infoheader.biSize)!=little_endian(40))
+	if(little_endian(infoheader.biSize)!=sizeof(synfig::BITMAP::INFOHEADER))
 	{
-		String str("bmp_mptr::get_frame(): "+strprintf(_("Bad BITMAPINFOHEADER in %s. (biSize=%d, should be 40)"),filename.c_str(),little_endian(infoheader.biSize)));
+		String str("bmp_mptr::get_frame(): "+strprintf(_("Bad BITMAP::INFOHEADER in %s. (biSize=%d, should be %d)"),identifier.filename.c_str(),little_endian(infoheader.biSize),sizeof(synfig::BITMAP::INFOHEADER)));
 		if(cb)cb->error(str);
 		else synfig::error(str);
 		return false;
@@ -209,12 +210,12 @@ bmp_mptr::get_frame(synfig::Surface &surface, const synfig::RendDesc &/*renddesc
 	for(y=0;y<surface.get_h();y++)
 		for(x=0;x<surface.get_w();x++)
 		{
-//			float b=(float)(unsigned char)fgetc(file)*(1.0/255.0);
-//			float g=(float)(unsigned char)fgetc(file)*(1.0/255.0);
-//			float r=(float)(unsigned char)fgetc(file)*(1.0/255.0);
-			float b=gamma().b_U8_to_F32((unsigned char)fgetc(file));
-			float g=gamma().g_U8_to_F32((unsigned char)fgetc(file));
-			float r=gamma().r_U8_to_F32((unsigned char)fgetc(file));
+//			float b=(float)(unsigned char)stream->getc()*(1.0/255.0);
+//			float g=(float)(unsigned char)stream->getc()*(1.0/255.0);
+//			float r=(float)(unsigned char)stream->getc()*(1.0/255.0);
+			float b=gamma().b_U8_to_F32((unsigned char)stream->get());
+			float g=gamma().g_U8_to_F32((unsigned char)stream->get());
+			float r=gamma().r_U8_to_F32((unsigned char)stream->get());
 
 			surface[h-y-1][x]=Color(
 				r,
@@ -223,11 +224,10 @@ bmp_mptr::get_frame(synfig::Surface &surface, const synfig::RendDesc &/*renddesc
 				1.0
 			);
 			if(bit_count==32)
-				fgetc(file);
+				stream->get();
 		}
 
 
-	fclose(file);
 	return true;
 }
 
