@@ -31,7 +31,7 @@
 
 /* === H E A D E R S ======================================================= */
 
-#include <synfig/layer_composite.h>
+#include <synfig/layers/layer_composite.h>
 #include <synfig/color.h>
 #include <synfig/vector.h>
 
@@ -62,6 +62,7 @@ public:
 	virtual Vocab get_param_vocab()const;
 
 	Layer::Handle hit_check(Context context, const Point &point)const;
+	using Layer::get_bounding_rect;
 	virtual Rect get_bounding_rect(Context context)const;
 
 	virtual bool accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
