@@ -114,7 +114,7 @@ CheckerBoard::set_param(const String &param, const ValueBase &value)
 		return set_param("origin", value);
 
 	for(int i=0;i<2;i++)
-		if(param==strprintf("pos[%d]",i) && value.get_type()==ValueBase::TYPE_REAL)
+		if(param==strprintf("pos[%d]",i) && value.get_type()==type_real)
 		{
 			Point p=param_origin.get(Point());
 			p[i]=value.get(Real());
@@ -194,6 +194,8 @@ CheckerBoard::get_color(Context context, const Point &getpos)const
 bool
 CheckerBoard::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
 {
+	RENDER_TRANSFORMED_IF_NEED(__FILE__, __LINE__)
+
 	Color color=param_color.get(Color());
 
 	SuperCallback supercb(cb,0,9500,10000);
