@@ -67,7 +67,7 @@ Circle::Circle():
 	param_radius    (Real(1)),
 	param_feather   (Real(0)),
 	param_invert    (bool(false)),
-	param_falloff   (FALLOFF_INTERPOLATION_LINEAR)
+	param_falloff   ((int)FALLOFF_INTERPOLATION_LINEAR)
 {
 	constructcache();
 	SET_INTERPOLATION_DEFAULTS();
@@ -453,6 +453,8 @@ Circle::get_color(Context context, const Point &point)const
 bool
 Circle::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
 {
+	RENDER_TRANSFORMED_IF_NEED(__FILE__, __LINE__)
+
 	Real radius = param_radius.get(Real());
 	Real feather = param_feather.get(Real());
 	Point origin = param_origin.get(Point());
