@@ -202,7 +202,7 @@ find_closest(bool fast, const std::vector<synfig::BLinePoint>& bline,const Point
 inline void
 CurveGradient::sync()
 {
-	std::vector<synfig::BLinePoint> bline(param_bline.get_list().begin(), param_bline.get_list().end());
+	std::vector<synfig::BLinePoint> bline(param_bline.get_list_of(BLinePoint()));
 	curve_length_=calculate_distance(bline, bline_loop);
 }
 
@@ -232,7 +232,7 @@ CurveGradient::CurveGradient():
 	bline[1].set_width(1.0f);
 	bline[2].set_width(1.0f);
 	bline_loop=true;
-	param_bline.set(bline);
+	param_bline.set_list_of(bline);
 
 	sync();
 
@@ -245,7 +245,7 @@ CurveGradient::color_func(const Point &point_, int quality, float supersample)co
 {
 	Point origin=param_origin.get(Point());
 	Real width=param_width.get(Real());
-	std::vector<synfig::BLinePoint> bline(param_bline.get_list().begin(), param_bline.get_list().end());
+	std::vector<synfig::BLinePoint> bline(param_bline.get_list_of(BLinePoint()));
 	Gradient gradient=param_gradient.get(Gradient());
 	bool loop=param_loop.get(bool());
 	bool zigzag=param_zigzag.get(bool());
@@ -340,7 +340,7 @@ CurveGradient::color_func(const Point &point_, int quality, float supersample)co
 
 			if (t<0.5)
 			{
-				if (iter->get_split_tangent_flag() || zero_tangent)
+				if (iter->get_split_tangent_angle() || iter->get_split_tangent_radius() || zero_tangent)
 				{
 					// fake the current tangent if we need to
 					if (zero_tangent) tangent = curve(FAKE_TANGENT_STEP) - curve(0);
@@ -366,7 +366,7 @@ CurveGradient::color_func(const Point &point_, int quality, float supersample)co
 			}
 			else
 			{
-				if (next->get_split_tangent_flag() || zero_tangent)
+				if (next->get_split_tangent_angle() || next->get_split_tangent_radius() || zero_tangent)
 				{
 					// fake the current tangent if we need to
 					if (zero_tangent) tangent = curve(1) - curve(1-FAKE_TANGENT_STEP);
@@ -504,7 +504,7 @@ CurveGradient::set_param(const String & param, const ValueBase &value)
 
 	IMPORT_VALUE(param_origin);
 	IMPORT_VALUE(param_width);
-	if(param=="bline" && value.get_type()==ValueBase::TYPE_LIST)
+	if(param=="bline" && value.get_type()==type_list)
 	{
 		param_bline=value;
 		bline_loop=value.get_loop();
@@ -571,7 +571,7 @@ CurveGradient::get_param_vocab()const
 	);
 	ret.push_back(ParamDesc("zigzag")
 				  .set_local_name(_("ZigZag"))
-				  .set_description(_("When checked the gradient is summetrical at the center"))
+				  .set_description(_("When checked the gradient is symmetrical at the center"))
 	);
 	ret.push_back(ParamDesc("perpendicular")
 				  .set_local_name(_("Perpendicular"))
@@ -598,6 +598,8 @@ CurveGradient::get_color(Context context, const Point &point)const
 bool
 CurveGradient::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
 {
+	RENDER_TRANSFORMED_IF_NEED(__FILE__, __LINE__)
+
 	SuperCallback supercb(cb,0,9500,10000);
 
 	if(get_amount()==1.0 && get_blend_method()==Color::BLEND_STRAIGHT)
