@@ -133,7 +133,7 @@ RadialGradient::get_param_vocab()const
 
 	ret.push_back(ParamDesc("zigzag")
 		.set_local_name(_("ZigZag"))
-		.set_description(_("When checked the gradient is summetrical at the center"))
+		.set_description(_("When checked the gradient is symmetrical at the center"))
 	);
 
 	return ret;
@@ -220,6 +220,8 @@ RadialGradient::get_color(Context context, const Point &pos)const
 bool
 RadialGradient::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
 {
+	RENDER_TRANSFORMED_IF_NEED(__FILE__, __LINE__)
+
 	SuperCallback supercb(cb,0,9500,10000);
 
 	if(get_amount()==1.0 && get_blend_method()==Color::BLEND_STRAIGHT)
