@@ -6,6 +6,7 @@
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2015 Jérôme Blanchi
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -42,10 +43,10 @@
 #include <synfig/time.h>
 #include <synfig/general.h>
 
-
 #include <cstdio>
 #include <algorithm>
 #include <functional>
+#include <sstream>
 #endif
 
 /* === M A C R O S ========================================================= */
@@ -63,6 +64,7 @@ SYNFIG_IMPORTER_SET_NAME(jpeg_mptr,"jpeg");
 SYNFIG_IMPORTER_SET_EXT(jpeg_mptr,"jpg");
 SYNFIG_IMPORTER_SET_VERSION(jpeg_mptr,"0.1");
 SYNFIG_IMPORTER_SET_CVS_ID(jpeg_mptr,"$Id$");
+SYNFIG_IMPORTER_SET_SUPPORTS_FILE_SYSTEM_WRAPPER(jpeg_mptr, false);
 
 /* === M E T H O D S ======================================================= */
 
@@ -96,19 +98,18 @@ jpeg_mptr::my_error_exit (j_common_ptr cinfo)
 
 
 
-jpeg_mptr::jpeg_mptr(const char *file_name)
+jpeg_mptr::jpeg_mptr(const synfig::FileSystem::Identifier &identifier):
+	Importer(identifier)
 {
-  	struct my_error_mgr jerr;
-	filename=file_name;
+	struct my_error_mgr jerr;
 
 	/* Open the file pointer */
-    FILE *file = fopen(file_name, "rb");
-    if (!file)
-    {
-        //! \todo THROW SOMETHING
-		throw String("error on importer construction, *WRITEME*1");
+	FileSystem::ReadStreamHandle stream = identifier.get_read_stream();
+	if (!stream)
+	{
+		throw String("Error on jpeg importer, unable to physically open "+identifier.filename);
 		return;
-    }
+	}
 
 	/* Step 1: allocate and initialize JPEG decompression object */
 
@@ -121,15 +122,20 @@ jpeg_mptr::jpeg_mptr(const char *file_name)
 		 * We need to clean up the JPEG object, close the input file, and return.
 		 */
 		jpeg_destroy_decompress(&cinfo);
-		fclose(file);
-		throw String("error on importer construction, *WRITEME*2");
+		stream.reset();
+		throw String("Error on jpeg importer, unable to connect to jpeg library");
 	}
 	/* Now we can initialize the JPEG decompression object. */
 	jpeg_create_decompress(&cinfo);
 
-	/* Step 2: specify data source (eg, a file) */
+	/* Step 2: specify data source (eg, from memory thrue a String) */
 
-	jpeg_stdio_src(&cinfo, file);
+	std::ostringstream tmp;
+	tmp << stream->rdbuf();
+	String streamString = tmp.str();
+	stream.reset();
+
+	jpeg_mem_src(&cinfo, (unsigned char*)streamString.c_str(), streamString.size());
 
 	/* Step 3: read file parameters with jpeg_read_header() */
 
@@ -161,8 +167,8 @@ jpeg_mptr::jpeg_mptr(const char *file_name)
 
 	if(!buffer)
 	{
-		synfig::error("jpeg_mptr: error: alloc of \"buffer\" failed (bug?)");
-		throw String("alloc of \"buffer\" failed (bug?)");
+		synfig::error("Error on jpeg importer, alloc of \"buffer\" failed (bug?)");
+		throw String("Error on jpeg importer, alloc of \"buffer\" failed (bug?)");
 	}
 
 	int x;
@@ -218,9 +224,9 @@ jpeg_mptr::jpeg_mptr(const char *file_name)
 		break;
 
 	default:
-		synfig::error("jpeg_mptr: error: Unsupported color type");
+		synfig::error("Error on jpeg importer, Unsupported color type");
         //! \todo THROW SOMETHING
-		throw String("error on importer construction, *WRITEME*6");
+		throw String("Error on jpeg importer, Unsupported color type");
 		return;
 	}
 
@@ -241,7 +247,7 @@ jpeg_mptr::jpeg_mptr(const char *file_name)
 	* so as to simplify the setjmp error logic above.  (Actually, I don't
 	* think that jpeg_destroy can do an error exit, but why assume anything...)
 	*/
-	fclose(file);
+//	fclose(file);
 }
 
 jpeg_mptr::~jpeg_mptr()
