@@ -32,7 +32,7 @@
 #include <synfig/vector.h>
 #include <synfig/valuenode.h>
 
-#include <synfig/layer_composite.h>
+#include <synfig/layers/layer_composite.h>
 #include <synfig/gradient.h>
 #include <synfig/time.h>
 #include "random_noise.h"
