@@ -56,17 +56,31 @@ SYNFIG_CAIROIMPORTER_SET_NAME(cairo_png_mptr,"cairo_png");
 SYNFIG_CAIROIMPORTER_SET_EXT(cairo_png_mptr,"png");
 SYNFIG_CAIROIMPORTER_SET_VERSION(cairo_png_mptr,"0.1");
 SYNFIG_CAIROIMPORTER_SET_CVS_ID(cairo_png_mptr,"$Id$");
+SYNFIG_CAIROIMPORTER_SET_SUPPORTS_FILE_SYSTEM_WRAPPER(cairo_png_mptr, true);
 
 /* === M E T H O D S ======================================================= */
 
-
-cairo_png_mptr::cairo_png_mptr(const char *file_name)
+cairo_status_t
+cairo_png_mptr::read_callback(void *closure, unsigned char *data, unsigned int length)
 {
-	filename=file_name;
-	csurface_=cairo_image_surface_create_from_png(file_name);
+	unsigned int s = closure == NULL ? 0
+				 : ((FileSystem::ReadStream*)closure)->read_block(data, length);
+	if (s < length) {
+		memset(data + s, 0, length - s);
+		return CAIRO_STATUS_READ_ERROR;
+	}
+	return CAIRO_STATUS_SUCCESS;
+}
+
+cairo_png_mptr::cairo_png_mptr(const synfig::FileSystem::Identifier &identifier):
+	CairoImporter(identifier)
+{
+	FileSystem::ReadStreamHandle stream = identifier.get_read_stream();
+	csurface_=cairo_image_surface_create_from_png_stream(read_callback, stream.get());
+	stream.reset();
 	if(cairo_surface_status(csurface_))
 	{
-		throw strprintf("Unable to physically open %s",file_name);
+		throw strprintf("Unable to physically open %s",identifier.filename.c_str());
 		cairo_surface_destroy(csurface_);
 		csurface_=NULL;
 		return;
