@@ -36,10 +36,10 @@
 #include <png.h>
 #include <ETL/stringf>
 #include <cstdio>
-#include <cstring>
 #include <algorithm>
 #include <functional>
 #include <ETL/misc>
+#include <string.h>
 
 #endif
 
@@ -78,16 +78,18 @@ png_trgt::png_out_warning(png_struct *png_data,const char *msg)
 
 //Target *png_trgt::New(const char *filename){	return new png_trgt(filename);}
 
-png_trgt::png_trgt(const char *Filename,
-				   const synfig::TargetParam&  params )
-{
-	file=NULL;
-	filename=Filename;
-	buffer=NULL;
-	ready=false;
-	color_buffer=0;
-	sequence_separator=params.sequence_separator;
-}
+png_trgt::png_trgt(const char *Filename, const synfig::TargetParam &params):
+	file(NULL),
+	png_ptr(NULL),
+	info_ptr(NULL),
+	multi_image(),
+	ready(false),
+	imagecount(),
+	filename(Filename),
+	buffer(NULL),
+	color_buffer(NULL),
+	sequence_separator(params.sequence_separator)
+{ }
 
 png_trgt::~png_trgt()
 {
