@@ -46,6 +46,12 @@
 
 /* === M A C R O S ========================================================= */
 
+// This macros should be removed when rendering optimization complete
+#define RENDER_TRANSFORMED_IF_NEED(file, line) \
+	if (!renddesc.get_transformation_matrix().is_identity()) \
+		return render_transformed(this, context, surface, quality, renddesc, cb, file, line);
+
+
 //! Defines various variables and the create method, common for all importers.
 //! To be used in the private part of the importer class definition.
 #define SYNFIG_LAYER_MODULE_EXT															\
@@ -84,21 +90,25 @@
 #define IMPORT_VALUE(x)                                                         \
 	if (#x=="param_"+param && x.get_type()==value.get_type())                   \
 	{                                                                           \
-		x.copy(value);                                                                \
+		x=value;                                                                \
 		return true;                                                            \
 	}
 
 //! Imports a parameter 'x' and perform an action usually based on
 //! some condition 'y'
-#define IMPORT_VALUE_PLUS(x,y)                                                  \
+#define IMPORT_VALUE_PLUS_BEGIN(x)                                              \
 	if (#x=="param_"+param && x.get_type()==value.get_type())                   \
 	{                                                                           \
 		x=value;                                                                \
-		{                                                                       \
-			y;                                                                  \
+		{
+#define IMPORT_VALUE_PLUS_END                                                   \
 		}                                                                       \
 		return true;                                                            \
 	}
+#define IMPORT_VALUE_PLUS(x,y)                                                  \
+        IMPORT_VALUE_PLUS_BEGIN(x)                                              \
+			y;                                                                  \
+        IMPORT_VALUE_PLUS_END
 
 //! Exports a parameter if it is the same type as value
 #define EXPORT_VALUE(x)                                                         \
@@ -208,7 +218,7 @@ public:
 		String category;
 		String cvs_id;
 		String version;
-		BookEntry() { }
+		BookEntry(): factory() { }
 		BookEntry(Factory		 factory,
 				  const String	&name,
 				  const String	&local_name,
@@ -272,6 +282,9 @@ private:
 	*/
 	bool active_;
 
+	//! flag to prevent re-apply optimization features
+	bool optimized_;
+
 	/*! When \c true, layer will skipped while final rendering
 	**	but will still present onto work view.
 	**	\see set_exclude_from_rendering(), get_exclude_from_rendering()
@@ -397,6 +410,12 @@ public:
 	//! Returns that status of the 'active' flag
 	bool active()const { return active_; }
 
+	//! flag to prevent re-apply optimization features
+	bool optimized()const { return optimized_; }
+
+	//! set flag to prevent re-apply optimization features
+	void set_optimized(bool x) { optimized_ = x; }
+
 	//! Sets the 'exclude_from_rendering' flag for the Layer
 	/*! When set, layer will skipped while final rendering
 	**	but will still present onto work view. */
@@ -415,6 +434,9 @@ public:
 	//! Gets the z depth of the layer at a time t
 	float get_z_depth(const synfig::Time& t)const;
 
+	//! Gets the true z depth of the layer (index + parameter)
+	float get_true_z_depth(const synfig::Time& t=Time(0))const;
+
 	//! Sets the z depth of the layer (non animated)
 	void set_z_depth(float x) { param_z_depth=ValueBase(Real(x)); }
 
@@ -439,6 +461,11 @@ public:
 	//! Returns the localised version of the given layer parameter
 	const String get_param_local_name(const String &param_name)const;
 
+	//! Returns a handle to the Parent PasteCanvas layer or NULL if layer belongs to root canvas
+	/*! Notice that it could return the wrong handle to PasteCanvas if the layer */
+	/*! belongs to a exported canvas (canvas can be referenced multiple times)*/
+	Layer::LooseHandle get_parent_paste_canvas_layer()const;
+
 	/*
  --	** -- V I R T U A L   F U N C T I O N S -----------------------------------
 	*/
@@ -527,6 +554,9 @@ public:
 	//! Sets the render method to the layer. Not all layers uses this virtual member
 	virtual void set_render_method(Context context, RenderMethod x);
 	
+	// Temporary function to render transformed layer for leyers which yet not suppurt transformed rendering
+	static bool render_transformed(const Layer *layer, Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb, const char *file, int line);
+
 	//! Renders the Canvas to the given Surface in an accelerated manner
 	/*!	\param context		Context iterator referring to next Layer.
 	**	\param surface		Pointer to Surface to render to.
@@ -571,6 +601,8 @@ public:
 	//! Retrieves the grow value from its parent canvas
 	Real get_parent_canvas_grow_value()const;
 
+	virtual void fill_sound_processor(SoundProcessor &soundProcessor) const;
+
 protected:
 
 	//! This is called whenever a parameter is changed
