@@ -81,6 +81,7 @@ public:
 Layer_PasteCanvas::Layer_PasteCanvas():
 	param_origin(Point()),
 	param_transformation(Transformation()),
+	param_time_dilation (Real(1)),
 	param_time_offset (Time(0)),
 	depth(0),
 	extra_reference(false)
@@ -138,6 +139,11 @@ Layer_PasteCanvas::get_param_vocab()const
 		.set_description(_("Group content"))
 	);
 
+	ret.push_back(ParamDesc("time_dilation")
+		.set_local_name(_("Speed"))
+		.set_description(_("Multiplier to speed up, slow down, freeze, or reverse time"))
+	);
+
 	ret.push_back(ParamDesc("time_offset")
 		.set_local_name(_("Time Offset"))
 		.set_description(_("Time Offset to apply to the context"))
@@ -204,6 +210,7 @@ Layer_PasteCanvas::set_param(const String & param, const ValueBase &value)
 		return true;
 	}
 #else
+	IMPORT_VALUE(param_time_dilation);
 	IMPORT_VALUE(param_time_offset);
 #endif
 
@@ -291,6 +298,7 @@ Layer_PasteCanvas::get_param(const String& param)const
 		synfig::ValueBase ret(canvas);
 		return ret;
 	}
+	EXPORT_VALUE(param_time_dilation);
 	EXPORT_VALUE(param_time_offset);
 	EXPORT_VALUE(param_children_lock);
 	EXPORT_VALUE(param_curr_time);
@@ -302,6 +310,7 @@ Layer_PasteCanvas::get_param(const String& param)const
 void
 Layer_PasteCanvas::set_time(IndependentContext context, Time time)const
 {
+	Real time_dilation=param_time_dilation.get(Real());
 	Time time_offset=param_time_offset.get(Time());
 
 	if(depth==MAX_DEPTH)return;depth_counter counter(depth);
@@ -309,7 +318,7 @@ Layer_PasteCanvas::set_time(IndependentContext context, Time time)const
 
 	context.set_time(time);
 	if(canvas)
-		canvas->set_time(time+time_offset);
+		canvas->set_time(time*time_dilation+time_offset);
 }
 
 void
@@ -391,6 +400,7 @@ Layer_PasteCanvas::accelerated_render(Context context,Surface *surface,int quali
 	  * renddesc.get_transformation_matrix() );
 
 	Real outline_grow=param_outline_grow.get(Real());
+	Real time_dilation=param_time_dilation.get(Real());
 	Time time_offset=param_time_offset.get(Time());
 	Time curr_time=param_curr_time.get(Time());
 
@@ -427,7 +437,7 @@ Layer_PasteCanvas::accelerated_render(Context context,Surface *surface,int quali
 	canvas->set_grow_value(outline_grow+grow_value);
 
 	if(muck_with_time_ && curr_time!=Time::begin() /*&& canvas->get_time()!=curr_time+time_offset*/)
-		canvas->set_time(curr_time+time_offset);
+		canvas->set_time(curr_time*time_dilation+time_offset);
 
 	Color::BlendMethod blend_method(get_blend_method());
 	const Rect full_bounding_rect(canvasContext.get_full_bounding_rect());
@@ -543,6 +553,7 @@ Layer_PasteCanvas::accelerated_cairorender(Context context,cairo_t *cr, int qual
 	Transformation transformation(get_summary_transformation());
 
 	Real outline_grow=param_outline_grow.get(Real());
+	Real time_dilation=param_time_dilation.get(Real());
 	Time time_offset=param_time_offset.get(Time());
 	Time curr_time=param_curr_time.get(Time());
 
@@ -563,12 +574,6 @@ Layer_PasteCanvas::accelerated_cairorender(Context context,cairo_t *cr, int qual
 	SuperCallback stagethree(cb,9000,9999,10000);
 
 
-	Real grow_value(get_parent_canvas_grow_value());
-	canvas->set_grow_value(outline_grow+grow_value);
-
-	if(muck_with_time_ && curr_time!=Time::begin() /*&& canvas->get_time()!=curr_time+time_offset*/)
-		canvas->set_time(curr_time+time_offset);
-
 	bool ret;
 	RendDesc workdesc(renddesc);
 
@@ -577,6 +582,12 @@ Layer_PasteCanvas::accelerated_cairorender(Context context,cairo_t *cr, int qual
 	if(!ret)
 		return false;
 
+	Real grow_value(get_parent_canvas_grow_value());
+	canvas->set_grow_value(outline_grow+grow_value);
+
+	if(muck_with_time_ && curr_time!=Time::begin() /*&& canvas->get_time()!=curr_time+time_offset*/)
+		canvas->set_time(curr_time*time_dilation+time_offset);
+
 
 	// render the canvas to be pasted onto pastesurface
 	cairo_surface_t* pastesurface=cairo_surface_create_similar_image(cairo_get_target(cr), CAIRO_FORMAT_ARGB32, workdesc.get_w(), workdesc.get_h());
@@ -636,6 +647,7 @@ Layer_PasteCanvas::accelerated_cairorender(Context context,cairo_t *cr, int qual
 
 void Layer_PasteCanvas::get_times_vfunc(Node::time_set &set) const
 {
+	Real time_dilation=param_time_dilation.get(Real());
 	Time time_offset=param_time_offset.get(Time());
 
 	Node::time_set tset;
@@ -646,12 +658,18 @@ void Layer_PasteCanvas::get_times_vfunc(Node::time_set &set) const
 	//Make sure we offset the time...
 	//! \todo: SOMETHING STILL HAS TO BE DONE WITH THE OTHER DIRECTION
 	//		   (recursing down the tree needs to take this into account too...)
-	for(; i != end; ++i)
-		set.insert(*i
+	for(; i != end; ++i) {
 #ifdef ADJUST_WAYPOINTS_FOR_TIME_OFFSET // see node.h
-				   - time_offset
+		if (time_dilation!=0)
+		{
+			TimePoint tp = *i;
+			tp.set_time((tp.get_time() - time_offset) / time_dilation);
+			set.insert(tp);
+		}
+#else
+		set.insert(*i);
 #endif
-			);
+	}
 
 	Layer::get_times_vfunc(set);
 }
