@@ -32,6 +32,7 @@
 
 #include "listimporter.h"
 #include "general.h"
+#include "filesystemnative.h"
 #include <fstream>
 
 #endif
@@ -53,35 +54,39 @@ SYNFIG_IMPORTER_SET_NAME(ListImporter,"lst");
 SYNFIG_IMPORTER_SET_EXT(ListImporter,"lst");
 SYNFIG_IMPORTER_SET_VERSION(ListImporter,"0.1");
 SYNFIG_IMPORTER_SET_CVS_ID(ListImporter,"$Id$");
+SYNFIG_IMPORTER_SET_SUPPORTS_FILE_SYSTEM_WRAPPER(ListImporter, false);
 
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
 
-ListImporter::ListImporter(const String &filename)
+//TODO factorize code with cairolistimporter.cpp
+ListImporter::ListImporter(const FileSystem::Identifier &identifier):
+Importer(identifier)
 {
 	fps=15;
 
-	ifstream stream(filename.c_str());
+	ifstream stream(identifier.filename.c_str());
 
 	if(!stream)
 	{
-		synfig::error("Unable to open "+filename);
+		synfig::error("Unable to open "+identifier.filename);
 		return;
 	}
-	String line;
-	String prefix=etl::dirname(filename)+ETL_DIRECTORY_SEPARATOR;
-	getline(stream,line);		// read first line and check whether it is a Papagayo lip sync file
 
-	if (line == "MohoSwitch1")	// it is a Papagayo lipsync file
+	String line;
+	String prefix=etl::dirname(identifier.filename)+ETL_DIRECTORY_SEPARATOR;
+
+	///! read first line and check whether it is a Papagayo lip sync file
+	if(!FileSystem::safeGetline(stream, line).eof())
+	if (line == "MohoSwitch1")
 	{
+		//! it is a Papagayo lipsync file
 		String phoneme, prevphoneme, prevext, ext(".jpg"); // default image format
 		int frame, prevframe = -1; // it means that the previous phoneme is not known
 
-		while(!stream.eof())
+		while(!FileSystem::safeGetline(stream, line).eof())
 		{
-			getline(stream,line);
-
 			if(line.find(String("FPS ")) == 0)
 			{
 				float f = atof(String(line.begin()+4,line.end()).c_str());
@@ -99,8 +104,8 @@ ListImporter::ListImporter(const String &filename)
 				ext = String(".") + line;
 				continue;
 			}
-
-			size_t pos = line.find(String(" ")); // find space position. The format is "frame phoneme-name".
+			//! find space position. The format is "frame phoneme-name".
+			size_t pos = line.find(String(" "));
 			if(pos != String::npos)
 			{
 				frame = atoi(String(line.begin(),line.begin()+pos).c_str());
@@ -127,12 +132,11 @@ ListImporter::ListImporter(const String &filename)
 	}
 
 	stream.seekg(ios_base::beg);
-	while(!stream.eof())
+	while(!FileSystem::safeGetline(stream, line).eof())
 	{
-		getline(stream,line);
 		if(line.empty())
 			continue;
-		// If we have a framerate, then use it
+		//! If we have a framerate, then use it
 		if(line.find(String("FPS "))==0)
 		{
 			fps=atof(String(line.begin()+4,line.end()).c_str());
@@ -178,7 +182,7 @@ ListImporter::get_frame(Surface &surface, const RendDesc &renddesc, Time time, P
 		}
 	}
 
-	Importer::Handle importer(Importer::open(filename_list[frame]));
+	Importer::Handle importer(Importer::open(FileSystem::Identifier(FileSystemNative::instance(), filename_list[frame])));
 
 	if(!importer)
 	{
