@@ -62,6 +62,7 @@
 #include <time.h>
 #include "layer.h"
 #include "valuenode.h"
+#include "soundprocessor.h"
 
 #include "main.h"
 #include "loadcanvas.h"
@@ -76,6 +77,10 @@
 
 #endif
 
+#ifndef PATH_MAX
+#define PATH_MAX 4096
+#endif
+
 using namespace std;
 using namespace etl;
 using namespace synfig;
@@ -193,8 +198,10 @@ synfig::Main::Main(const synfig::String& basepath,ProgressCallback *cb):
 
 	unsigned int i;
 #ifdef _DEBUG
+#ifndef __APPLE__
 	std::set_terminate(__gnu_cxx::__verbose_terminate_handler);
 #endif
+#endif
 
 #if defined(HAVE_SIGNAL_H) && defined(SIGPIPE)
 	signal(SIGPIPE, broken_pipe_signal);
@@ -204,14 +211,27 @@ synfig::Main::Main(const synfig::String& basepath,ProgressCallback *cb):
 
 	// Init the subsystems
 	if(cb)cb->amount_complete(0, 100);
+
+	if(cb)cb->task(_("Starting Subsystem \"Sound\""));
+	if(!SoundProcessor::subsys_init())
+		throw std::runtime_error(_("Unable to initialize subsystem \"Sound\""));
+
+	if(cb)cb->task(_("Starting Subsystem \"Types\""));
+	if(!Type::subsys_init())
+		throw std::runtime_error(_("Unable to initialize subsystem \"Types\""));
+
 	if(cb)cb->task(_("Starting Subsystem \"Modules\""));
 	if(!Module::subsys_init(prefix))
-		throw std::runtime_error(_("Unable to initialize subsystem \"Module\""));
+	{
+		Type::subsys_stop();
+		throw std::runtime_error(_("Unable to initialize subsystem \"Modules\""));
+	}
 
 	if(cb)cb->task(_("Starting Subsystem \"Layers\""));
 	if(!Layer::subsys_init())
 	{
 		Module::subsys_stop();
+		Type::subsys_stop();
 		throw std::runtime_error(_("Unable to initialize subsystem \"Layers\""));
 	}
 
@@ -220,6 +240,7 @@ synfig::Main::Main(const synfig::String& basepath,ProgressCallback *cb):
 	{
 		Layer::subsys_stop();
 		Module::subsys_stop();
+		Type::subsys_stop();
 		throw std::runtime_error(_("Unable to initialize subsystem \"Targets\""));
 	}
 
@@ -229,6 +250,7 @@ synfig::Main::Main(const synfig::String& basepath,ProgressCallback *cb):
 		Target::subsys_stop();
 		Layer::subsys_stop();
 		Module::subsys_stop();
+		Type::subsys_stop();
 		throw std::runtime_error(_("Unable to initialize subsystem \"Importers\""));
 	}
 
@@ -239,6 +261,7 @@ synfig::Main::Main(const synfig::String& basepath,ProgressCallback *cb):
 		Target::subsys_stop();
 		Layer::subsys_stop();
 		Module::subsys_stop();
+		Type::subsys_stop();
 		throw std::runtime_error(_("Unable to initialize subsystem \"Cairo Importers\""));
 	}
 
@@ -250,12 +273,13 @@ synfig::Main::Main(const synfig::String& basepath,ProgressCallback *cb):
 		Target::subsys_stop();
 		Layer::subsys_stop();
 		Module::subsys_stop();
+		Type::subsys_stop();
 		throw std::runtime_error(_("Unable to initialize subsystem \"ValueNodes\""));
 	}
 
 	// Load up the list importer
-	Importer::book()[String("lst")]=ListImporter::create;
-	CairoImporter::book()[String("lst")]=CairoListImporter::create;
+	Importer::book()[String("lst")]=Importer::BookEntry(ListImporter::create, ListImporter::supports_file_system_wrapper__);
+	CairoImporter::book()[String("lst")]=CairoImporter::BookEntry(CairoListImporter::create, CairoListImporter::supports_file_system_wrapper__);
 
 	// Load up the modules
 	std::list<String> modules_to_load;
@@ -267,7 +291,7 @@ synfig::Main::Main(const synfig::String& basepath,ProgressCallback *cb):
 	{
 		locations.push_back("./"MODULE_LIST_FILENAME);
 		if(getenv("HOME"))
-			locations.push_back(strprintf("%s/.synfig/%s", getenv("HOME"), MODULE_LIST_FILENAME));
+			locations.push_back(strprintf("%s/.local/share/synfig/%s", getenv("HOME"), MODULE_LIST_FILENAME));
 	#ifdef SYSCONFDIR
 		locations.push_back(SYSCONFDIR"/"MODULE_LIST_FILENAME);
 	#endif
@@ -299,6 +323,7 @@ synfig::Main::Main(const synfig::String& basepath,ProgressCallback *cb):
 		Target::subsys_stop();
 		Layer::subsys_stop();
 		Module::subsys_stop();
+		Type::subsys_stop();
 		throw std::runtime_error(strprintf(_("Unable to open module list file '%s'"), MODULE_LIST_FILENAME));
 	}
 
@@ -349,6 +374,7 @@ synfig::Main::~Main()
  	// synfig::info("Module::subsys_stop()");
 	// Module::subsys_stop();
 	// synfig::info("Exiting");
+	Type::subsys_stop();
 
 #if defined(HAVE_SIGNAL_H) && defined(SIGPIPE)
 	signal(SIGPIPE, SIG_DFL);
