@@ -31,6 +31,7 @@
 
 #include "module.h"
 #include "general.h"
+#include "type.h"
 #include <ETL/stringf>
 
 #ifndef USE_CF_BUNDLES
@@ -68,7 +69,7 @@ Module::subsys_init(const String &prefix)
 
 	lt_dladdsearchdir(".");
 	if(getenv("HOME"))
-		lt_dladdsearchdir(strprintf("%s/.synfig/modules", getenv("HOME")).c_str());
+		lt_dladdsearchdir(strprintf("%s/.local/share/synfig/modules", getenv("HOME")).c_str());
 	lt_dladdsearchdir((prefix+"/lib/synfig/modules").c_str());
 #ifdef LIBDIR
 	lt_dladdsearchdir(LIBDIR"/synfig/modules");
@@ -127,6 +128,7 @@ synfig::Module::Register(const String &module_name, ProgressCallback *callback)
 
 	module=lt_dlopenext((string("lib")+module_name).c_str());
 	if(!module)module=lt_dlopenext(module_name.c_str());
+	Type::initialize_all();
 
 	if(!module)
 	{
