@@ -31,8 +31,8 @@
 #endif
 
 #include "timepointcollect.h"
-#include "valuenode_animated.h"
-#include "layer_pastecanvas.h"
+#include <synfig/valuenodes/valuenode_animated.h>
+#include <synfig/layers/layer_pastecanvas.h>
 #include "layer.h"
 #include "canvas.h"
 #include "value.h"
