@@ -7,7 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
-**	Copyright (c) 2009-2012 Diego Barrios Romero
+**	Copyright (c) 2009-2015 Diego Barrios Romero
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -35,24 +35,25 @@
 #include <errno.h>
 #include <cstring>
 
+#include <boost/filesystem.hpp>
 #include <boost/program_options/options_description.hpp>
 #include <boost/program_options/variables_map.hpp>
+#include <boost/format.hpp>
+#include <boost/chrono.hpp>
 
-#include <ETL/stringf>
-#include <ETL/clock>
 #include <autorevision.h>
 #include <synfig/general.h>
 #include <synfig/canvas.h>
 #include <synfig/target.h>
 #include <synfig/layer.h>
 #include <synfig/time.h>
-#include <synfig/targetparam.h>
 #include <synfig/target_scanline.h>
 #include <synfig/paramdesc.h>
 #include <synfig/module.h>
 #include <synfig/importer.h>
 #include <synfig/loadcanvas.h>
 #include <synfig/savecanvas.h>
+#include <synfig/filesystemnative.h>
 
 #include "definitions.h"
 #include "job.h"
@@ -63,11 +64,10 @@
 
 #endif
 
-using namespace std;
 using namespace synfig;
-using namespace etl;
+namespace bfs=boost::filesystem;
 
-void process_job_list(list<Job>& job_list, const TargetParam& target_params) throw (SynfigToolException&)
+void process_job_list(std::list<Job>& job_list, const TargetParam& target_params)
 {
 	if(!job_list.size())
 		throw (SynfigToolException(SYNFIGTOOL_BORED, _("Nothing to do!")));
@@ -81,15 +81,15 @@ void process_job_list(list<Job>& job_list, const TargetParam& target_params) thr
 
 bool setup_job(Job& job, const TargetParam& target_parameters)
 {
-	VERBOSE_OUT(4) << _("Attempting to determine target/outfile...") << endl;
+	VERBOSE_OUT(4) << _("Attempting to determine target/outfile...") << std::endl;
 
 	// If the target type is not yet defined,
 	// try to figure it out from the outfile.
 	if(job.target_name.empty() && !job.outfilename.empty())
 	{
 		VERBOSE_OUT(3) << _("Target name undefined, attempting to figure it out")
-					   << endl;
-		string ext = filename_extension(job.outfilename);
+					   << std::endl;
+		std::string ext = bfs::path(job.outfilename).extension().string();
 		if (ext.length())
 			ext = ext.substr(1);
 
@@ -100,10 +100,8 @@ bool setup_job(Job& job, const TargetParam& target_parameters)
 		}
 		else
 		{
-			string lower_ext(ext);
-
-			for(unsigned int i = 0; i < ext.length(); i++)
-				lower_ext[i] = tolower(ext[i]);
+			std::string lower_ext;
+			std::transform(ext.begin(), ext.end(), std::back_inserter(lower_ext), ::tolower);
 
 			if(Target::ext_book().count(lower_ext))
 			{
@@ -119,7 +117,7 @@ bool setup_job(Job& job, const TargetParam& target_parameters)
 	// set it to a some sort of default
 	if(job.target_name.empty())
 	{
-		VERBOSE_OUT(2) << _("Defaulting to PNG target...") << endl;
+		VERBOSE_OUT(2) << _("Defaulting to PNG target...") << std::endl;
 		job.target_name = "png";
 	}
 
@@ -128,29 +126,30 @@ bool setup_job(Job& job, const TargetParam& target_parameters)
 	// (ie: change the extension)
 	if(job.outfilename.empty())
 	{
-		job.outfilename =
-			filename_sans_extension(job.filename) + '.';
-
+        std::string new_extension;
 		if(Target::book().count(job.target_name))
-			job.outfilename +=
-				Target::book()[job.target_name].filename;
+			new_extension = Target::book()[job.target_name].filename;
 		else
-			job.outfilename += job.target_name;
+			new_extension = job.target_name;
+
+        job.outfilename = bfs::path(job.filename).replace_extension(new_extension).string();
 	}
 
-	VERBOSE_OUT(4) << "Target name = " << job.target_name.c_str() << endl;
-	VERBOSE_OUT(4) << "Outfilename = " << job.outfilename.c_str() << endl;
+	VERBOSE_OUT(4) << "Target name = " << job.target_name.c_str() << std::endl;
+	VERBOSE_OUT(4) << "Outfilename = " << job.outfilename.c_str() << std::endl;
 
 	// Check permissions
-	if (access(dirname(job.outfilename).c_str(), W_OK) == -1)
+	if (access(bfs::canonical(bfs::path(job.outfilename).parent_path()).string().c_str(), W_OK) == -1)
 	{
-		VERBOSE_OUT(1) << _("Unable to create ouput for \"") << job.filename.c_str()
-						<< "\": " << strerror(errno) << endl
-					   << _("Throwing out job...") << endl;
+	    const std::string message =
+            (boost::format(_("Unable to create output for \"%s\": %s"))
+                           % job.filename % strerror(errno)).str();
+		synfig::error(message.c_str());
+		synfig::error(_("Throwing out job..."));
 		return false;
 	}
 
-	VERBOSE_OUT(4) << _("Creating the target...") << endl;
+	VERBOSE_OUT(4) << _("Creating the target...") << std::endl;
 	job.target =
 		synfig::Target::create(job.target_name,
 							   job.outfilename,
@@ -162,10 +161,12 @@ bool setup_job(Job& job, const TargetParam& target_parameters)
 	{
 		if(!job.target)
 		{
-			VERBOSE_OUT(1) << _("Unknown target for \"") << job.filename.c_str()
-						   << "\": " << strerror(errno) << endl
-						   << _("Throwing out job...") << endl;
-			return false;
+		    const std::string message =
+                (boost::format(_("Unknown target for \"%s\": %s"))
+                               % job.filename % strerror(errno)).str();
+		    synfig::error(message.c_str());
+                    synfig::error(_("Throwing out job..."));
+                    return false;
 		}
 
 		job.sifout=false;
@@ -174,76 +175,80 @@ bool setup_job(Job& job, const TargetParam& target_parameters)
 	// Set the Canvas on the Target
 	if(job.target)
 	{
-		VERBOSE_OUT(4) << _("Setting the canvas on the target...") << endl;
+		VERBOSE_OUT(4) << _("Setting the canvas on the target...") << std::endl;
 		job.target->set_canvas(job.canvas);
 
-		VERBOSE_OUT(4) << _("Setting the quality of the target...") << endl;
+		VERBOSE_OUT(4) << _("Setting the quality of the target...") << std::endl;
 		job.target->set_quality(job.quality);
-		
+
 		if (job.alpha_mode!=TARGET_ALPHA_MODE_KEEP)
 		{
-			VERBOSE_OUT(4) << _("Setting the alpha mode of the target...") << endl;
+			VERBOSE_OUT(4) << _("Setting the alpha mode of the target...") << std::endl;
 			job.target->set_alpha_mode(job.alpha_mode);
 		}
 	}
 
 	// Set the threads for the target
 	if (job.target && Target_Scanline::Handle::cast_dynamic(job.target))
-		Target_Scanline::Handle::cast_dynamic(job.target)->set_threads(threads);
+		Target_Scanline::Handle::cast_dynamic(job.target)->set_threads(SynfigToolGeneralOptions::instance()->get_threads());
 
 	return true;
 }
 
-void process_job (Job& job) throw (SynfigToolException&)
+void process_job (Job& job)
 {
-	VERBOSE_OUT(3) << job.filename.c_str() << " -- " << endl;
+	VERBOSE_OUT(3) << job.filename.c_str() << " -- " << std::endl;
 	VERBOSE_OUT(3) << '\t'
-				   <<
-		strprintf("w:%d, h:%d, a:%d, pxaspect:%f, imaspect:%f, span:%f",
-			job.desc.get_w(),
-			job.desc.get_h(),
-			job.desc.get_antialias(),
-			job.desc.get_pixel_aspect(),
-			job.desc.get_image_aspect(),
-			job.desc.get_span()
-			).c_str()
-		<< endl;
+				   << boost::format("w:%d, h:%d, a:%d, pxaspect:%f, imaspect:%f, span:%f")
+                                    % job.desc.get_w()
+                                    % job.desc.get_h()
+                                    % job.desc.get_antialias()
+                                    % job.desc.get_pixel_aspect()
+                                    % job.desc.get_image_aspect()
+                                    % job.desc.get_span()
+                    << std::endl;
 
 	VERBOSE_OUT(3) << '\t'
-				   <<
-		strprintf("tl:[%f,%f], br:[%f,%f], focus:[%f,%f]",
-			job.desc.get_tl()[0],
-			job.desc.get_tl()[1],
-			job.desc.get_br()[0],
-			job.desc.get_br()[1],
-			job.desc.get_focus()[0],
-			job.desc.get_focus()[1]
-			).c_str()
-			<< endl;
+				   << boost::format("tl:[%f,%f], br:[%f,%f], focus:[%f,%f]")
+                                    % job.desc.get_tl()[0]
+                                    % job.desc.get_tl()[1]
+                                    % job.desc.get_br()[0]
+                                    % job.desc.get_br()[1]
+                                    % job.desc.get_focus()[0]
+                                    % job.desc.get_focus()[1]
+                    << std::endl;
 
 	RenderProgress p;
 	p.task(job.filename + " ==> " + job.outfilename);
 
 	if(job.sifout)
 	{
-		if(!save_canvas(job.outfilename, job.canvas))
+		// todo: support containers
+		if(!save_canvas(FileSystemNative::instance()->get_identifier(job.outfilename), job.canvas))
 			throw (SynfigToolException(SYNFIGTOOL_RENDERFAILURE, _("Render Failure.")));
 	}
 	else
 	{
-		VERBOSE_OUT(1) << _("Rendering...") << endl;
-		etl::clock timer;
-		timer.reset();
+		VERBOSE_OUT(1) << _("Rendering...") << std::endl;
+		boost::chrono::system_clock::time_point start_timepoint =
+            boost::chrono::system_clock::now();
 
 		// Call the render member of the target
 		if(!job.target->render(&p))
 			throw (SynfigToolException(SYNFIGTOOL_RENDERFAILURE, _("Render Failure.")));
 
-		if(print_benchmarks)
-			cout << job.filename.c_str()
-				 << _(": Rendered in ") << timer()
-				 << _(" seconds.") << endl;
+		if(SynfigToolGeneralOptions::instance()->should_print_benchmarks())
+        {
+            boost::chrono::duration<double> duration =
+                boost::chrono::system_clock::now() - start_timepoint;
+
+            std::cout << job.filename.c_str()
+                      << _(": Rendered in ")
+                      << duration.count()
+                      << _(" seconds.") << std::endl;
+        }
 	}
 
-	VERBOSE_OUT(1) << _("Done.") << endl;
+	VERBOSE_OUT(1) << _("Done.") << std::endl;
 }
+
