@@ -7,7 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
-**	Copyright (c) 2009-2012 Diego Barrios Romero
+**	Copyright (c) 2009-2014 Diego Barrios Romero
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -30,11 +30,9 @@
 #endif
 
 #include <iostream>
+#include <boost/filesystem.hpp>
+#include <boost/format.hpp>
 
-#include <boost/program_options/options_description.hpp>
-#include <boost/program_options/variables_map.hpp>
-
-#include <ETL/stringf>
 #include <autorevision.h>
 #include <synfig/general.h>
 #include <synfig/canvas.h>
@@ -42,9 +40,13 @@
 #include <synfig/target.h>
 #include <synfig/layer.h>
 #include <synfig/module.h>
+#include <synfig/main.h>
 #include <synfig/importer.h>
 #include <synfig/loadcanvas.h>
 #include <synfig/guid.h>
+#include <synfig/filesystemgroup.h>
+#include <synfig/filesystemnative.h>
+#include <synfig/filecontainerzip.h>
 
 #include "definitions.h"
 #include "job.h"
@@ -56,7 +58,29 @@
 
 using namespace std;
 using namespace synfig;
-using namespace etl;
+namespace bfs=boost::filesystem;
+
+OptionsProcessor::OptionsProcessor(
+	boost::program_options::variables_map& vm,
+	const boost::program_options::options_description& po_visible)
+		: _vm(vm), _po_visible(po_visible)
+{
+	_allowed_video_codecs.push_back(VideoCodec("flv", "Flash Video (FLV) / Sorenson Spark / Sorenson H.263."));
+	_allowed_video_codecs.push_back(VideoCodec("h263p", "H.263+ / H.263-1998 / H.263 version 2."));
+	_allowed_video_codecs.push_back(VideoCodec("huffyuv", "Huffyuv / HuffYUV."));
+	_allowed_video_codecs.push_back(VideoCodec("libtheora", "libtheora Theora."));
+	_allowed_video_codecs.push_back(VideoCodec("libx264", "H.264 / AVC / MPEG-4 AVC."));
+	_allowed_video_codecs.push_back(VideoCodec("libx264-lossless", "H.264 / AVC / MPEG-4 AVC (LossLess)."));
+	_allowed_video_codecs.push_back(VideoCodec("mjpeg", "MJPEG (Motion JPEG)."));
+	_allowed_video_codecs.push_back(VideoCodec("mpeg1video", "Raw MPEG-1 video."));
+	_allowed_video_codecs.push_back(VideoCodec("mpeg2video", "Raw MPEG-2 video."));
+	_allowed_video_codecs.push_back(VideoCodec("mpeg4", "MPEG-4 part 2 (XviD/DivX)."));
+	_allowed_video_codecs.push_back(VideoCodec("msmpeg4", "MPEG-4 part 2 Microsoft variant version 3."));
+	_allowed_video_codecs.push_back(VideoCodec("msmpeg4v1", "MPEG-4 part 2 Microsoft variant version 1."));
+	_allowed_video_codecs.push_back(VideoCodec("msmpeg4v2", "MPEG-4 part 2 Microsoft variant version 2."));
+	_allowed_video_codecs.push_back(VideoCodec("wmv1", "Windows Media Video 7."));
+	_allowed_video_codecs.push_back(VideoCodec("wmv2", "Windows Media Video 8."));
+}
 
 void OptionsProcessor::extract_canvas_info(Job& job)
 {
@@ -128,26 +152,32 @@ void OptionsProcessor::process_settings_options()
 {
 	if (_vm.count("verbose"))
 	{
-		verbosity = _vm["verbose"].as<int>();
-		VERBOSE_OUT(1) << _("verbosity set to ") << verbosity
-					   << endl;
+		SynfigToolGeneralOptions::instance()->set_verbosity(_vm["verbose"].as<int>());
+		VERBOSE_OUT(1) << _("verbosity set to ")
+					   << SynfigToolGeneralOptions::instance()->get_verbosity()
+					   << std::endl;
 	}
 
 	if (_vm.count("benchmarks"))
-		print_benchmarks=true;
+	{
+		SynfigToolGeneralOptions::instance()->set_should_print_benchmarks(true);
+	}
 
 	if (_vm.count("quiet"))
-		be_quiet=true;
+	{
+		SynfigToolGeneralOptions::instance()->set_should_be_quiet(true);
+	}
 
 	if (_vm.count("threads"))
-		threads = _vm["threads"].as<int>();
-	else
-		threads = 1;
+	{
+		SynfigToolGeneralOptions::instance()->set_threads(_vm["threads"].as<size_t>());
+	}
 
-	VERBOSE_OUT(1) << _("Threads set to ") << threads << endl;
+	VERBOSE_OUT(1) << _("Threads set to ")
+				   << SynfigToolGeneralOptions::instance()->get_threads() << std::endl;
 }
 
-void OptionsProcessor::process_info_options() throw (SynfigToolException&)
+void OptionsProcessor::process_info_options()
 {
 	if (_vm.count("help"))
 	{
@@ -222,10 +252,10 @@ void OptionsProcessor::process_info_options() throw (SynfigToolException&)
 		Layer::Handle layer =
 			synfig::Layer::create(_vm["layer-info"].as<string>());
 
-		cout << _("Layer Name: ") << (layer->get_name()).c_str() << endl;
+		cout << _("Layer Name: ") << layer->get_name() << endl;
 		cout << _("Localized Layer Name: ")
-			 << (layer->get_local_name()).c_str() << endl;
-		cout << _("Version: ") << (layer->get_version()).c_str() << endl;
+			 << layer->get_local_name() << endl;
+		cout << _("Version: ") << layer->get_version() << endl;
 
 		Layer::Vocab vocab = layer->get_param_vocab();
 		for(; !vocab.empty(); vocab.pop_front())
@@ -307,23 +337,23 @@ RendDesc OptionsProcessor::extract_renddesc(const RendDesc& renddesc)
 		int a;
 		a = _vm["antialias"].as<int>();
 		desc.set_antialias(a);
-		VERBOSE_OUT(1) << strprintf(_("Antialiasing set to %d, "
-									  "(%d samples per pixel)"), a, a*a).c_str()
-						<< endl;
+		VERBOSE_OUT(1) << boost::format(_("Antialiasing set to %d, "
+										  "(%d samples per pixel)")) % a % (a*a)
+						<< std::endl;
 	}
 	if (_vm.count("span"))
 	{
-		span = _vm["span"].as<int>();
-		VERBOSE_OUT(1) << strprintf(_("Span set to %d units"), span).c_str()
-						<< endl;
+	    span = _vm["span"].as<int>();
+		VERBOSE_OUT(1) << boost::format(_("Span set to %d units")) % span
+                       << std::endl;
 	}
 	if (_vm.count("fps"))
 	{
 		float fps;
 		fps = _vm["fps"].as<float>();
 		desc.set_frame_rate(fps);
-		VERBOSE_OUT(1) << strprintf(_("Frame rate set to %d frames per "
-									  "second"), fps).c_str() << endl;
+		VERBOSE_OUT(1) << boost::format(_("Frame rate set to %d frames per "
+										   "second")) % fps << std::endl;
 	}
 	if (_vm.count("dpi"))
 	{
@@ -332,8 +362,8 @@ RendDesc OptionsProcessor::extract_renddesc(const RendDesc& renddesc)
 		dots_per_meter = dpi * 39.3700787402;
 		desc.set_x_res(dots_per_meter);
 		desc.set_y_res(dots_per_meter);
-		VERBOSE_OUT(1) << strprintf(_("Physical resolution set to %f "
-									  "dpi"), dpi).c_str() << endl;
+		VERBOSE_OUT(1) << boost::format(_("Physical resolution set to %f "
+                                          "dpi")) % dpi << std::endl;
 	}
 	if (_vm.count("dpi-x"))
 	{
@@ -341,8 +371,8 @@ RendDesc OptionsProcessor::extract_renddesc(const RendDesc& renddesc)
 		dpi = _vm["dpi-x"].as<float>();
 		dots_per_meter = dpi * 39.3700787402;
 		desc.set_x_res(dots_per_meter);
-		VERBOSE_OUT(1) << strprintf(_("Physical X resolution set to %f "
-									  "dpi"), dpi).c_str() << endl;
+		VERBOSE_OUT(1) << boost::format(_("Physical X resolution set to %f "
+										  "dpi")) % dpi << std::endl;
 	}
 	if (_vm.count("dpi-y"))
 	{
@@ -350,35 +380,31 @@ RendDesc OptionsProcessor::extract_renddesc(const RendDesc& renddesc)
 		dpi = _vm["dpi-y"].as<float>();
 		dots_per_meter = dpi * 39.3700787402;
 		desc.set_y_res(dots_per_meter);
-		VERBOSE_OUT(1) << strprintf(_("Physical Y resolution set to %f "
-									  "dpi"), dpi).c_str() << endl;
+		VERBOSE_OUT(1) << boost::format(_("Physical Y resolution set to %f "
+                                          "dpi")) % dpi << std::endl;
 	}
 	if (_vm.count("start-time"))
 	{
-		string seconds;
-		seconds = _vm["start-time"].as<string>();
+		std::string seconds = _vm["start-time"].as<std::string>();
 		desc.set_time_start(Time(seconds.c_str(), desc.get_frame_rate()));
 	}
 	if (_vm.count("begin-time"))
 	{
-		string seconds;
-		seconds = _vm["begin-time"].as<string>();
+		std::string seconds = _vm["begin-time"].as<std::string>();
 		desc.set_time_start(Time(seconds.c_str(), desc.get_frame_rate()));
 	}
 	if (_vm.count("end-time"))
 	{
-		string seconds;
-		seconds = _vm["end-time"].as<string>();
+		std::string seconds = _vm["end-time"].as<std::string>();
 		desc.set_time_end(Time(seconds.c_str(), desc.get_frame_rate()));
 	}
 	if (_vm.count("time"))
 	{
-		string seconds;
-		seconds = _vm["time"].as<string>();
+		std::string seconds = _vm["time"].as<std::string>();
 		desc.set_time(Time(seconds.c_str(), desc.get_frame_rate()));
 
 		VERBOSE_OUT(1) << _("Rendering frame at ")
-					   << desc.get_time_start().get_string(desc.get_frame_rate()).c_str()
+					   << desc.get_time_start().get_string(desc.get_frame_rate())
 					   << endl;
 	}
 	if (_vm.count("gamma"))
@@ -389,7 +415,7 @@ RendDesc OptionsProcessor::extract_renddesc(const RendDesc& renddesc)
 		//desc.set_gamma(Gamma(gamma));
 	}
 
-	if (w||h)
+	if (w || h)
 	{
 		// scale properly
 		if (!w)
@@ -397,9 +423,9 @@ RendDesc OptionsProcessor::extract_renddesc(const RendDesc& renddesc)
 		else if (!h)
 			h = desc.get_h() * w / desc.get_w();
 
-		desc.set_wh(w,h);
-		VERBOSE_OUT(1) << strprintf(_("Resolution set to %dx%d"), w, h).c_str()
-						<< endl;
+		desc.set_wh(w, h);
+		VERBOSE_OUT(1) << boost::format(_("Resolution set to %dx%d.")) % w % h
+                       << std::endl;
 	}
 
 	if(span)
@@ -408,7 +434,7 @@ RendDesc OptionsProcessor::extract_renddesc(const RendDesc& renddesc)
 	return desc;
 }
 
-TargetParam OptionsProcessor::extract_targetparam() throw (SynfigToolException&)
+TargetParam OptionsProcessor::extract_targetparam()
 {
 	TargetParam params;
 
@@ -419,7 +445,7 @@ TargetParam OptionsProcessor::extract_targetparam() throw (SynfigToolException&)
 
 	if (_vm.count("video-codec"))
 	{
-		params.video_codec = _vm["video-codec"].as<string>();
+		params.video_codec = _vm["video-codec"].as<std::string>();
 
 		// video_codec string to lowercase
 		transform (params.video_codec.begin(),
@@ -429,36 +455,44 @@ TargetParam OptionsProcessor::extract_targetparam() throw (SynfigToolException&)
 
 		bool found = false;
 		// Check if the given video codec is allowed.
-		for (int i = 0; !found && allowed_video_codecs[i] != NULL; i++)
-			if (params.video_codec == allowed_video_codecs[i])
+		for (std::vector<VideoCodec>::const_iterator itr = _allowed_video_codecs.begin();
+		 itr != _allowed_video_codecs.end(); ++itr)
+		{
+			if (params.video_codec == itr->name)
+			{
 				found = true;
+			}
+		}
 
 		if (!found)
-			throw(SynfigToolException(SYNFIGTOOL_UNKNOWNARGUMENT,
-									   strprintf(_("Video codec \"%s\" is not supported."),
-											   	 params.video_codec.c_str())));
+		{
+		    throw SynfigToolException(SYNFIGTOOL_UNKNOWNARGUMENT,
+                                      (boost::format(_("Video codec \"%s\" is not supported."))
+                                                      % params.video_codec).str());
+		}
 
-		VERBOSE_OUT(1) << strprintf(_("Target video codec set to %s"), params.video_codec.c_str()).c_str()
-						<< endl;
+		VERBOSE_OUT(1) << _("Target video codec set to: ") << params.video_codec
+                       << std::endl;
 	}
 	if(_vm.count("video-bitrate"))
 	{
 		params.bitrate = _vm["video-bitrate"].as<int>();
-		VERBOSE_OUT(1) << strprintf(_("Target bitrate set to %dk"),params.bitrate).c_str()
-					   << endl;
+		VERBOSE_OUT(1) << _("Target bitrate set to: ") << params.bitrate << "k."
+					   << std::endl;
 	}
 	if(_vm.count("sequence-separator"))
 	{
-		params.sequence_separator = _vm["sequence-separator"].as<string>();
-		VERBOSE_OUT(1) << strprintf(_("Output file sequence separator set to %s"),
-									params.sequence_separator.c_str()).c_str()
-					   << endl;
+		params.sequence_separator = _vm["sequence-separator"].as<std::string>();
+		VERBOSE_OUT(1) << _("Output file sequence separator set to: '")
+                       << params.sequence_separator
+                       << "'."
+					   << std::endl;
 	}
 
 	return params;
 }
 
-Job OptionsProcessor::extract_job() throw (SynfigToolException&)
+Job OptionsProcessor::extract_job()
 {
 	Job job;
 
@@ -471,7 +505,23 @@ Job OptionsProcessor::extract_job() throw (SynfigToolException&)
 		string errors, warnings;
 		try
 		{
-			job.root = open_canvas(job.filename, errors, warnings);
+			// todo: literals ".sfg", "container:", "project.sifz"
+			if (bfs::path(job.filename).extension().string() == ".sfg")
+			{
+				etl::handle< FileContainerZip > container = new FileContainerZip();
+				if (container->open(job.filename))
+				{
+					etl::handle< FileSystemGroup > file_system( new FileSystemGroup(FileSystemNative::instance()) );
+					file_system->register_system("#", container);
+					job.root = open_canvas_as(file_system->get_identifier("#project.sifz"), job.filename, errors, warnings);
+				} else
+				{
+					errors.append("Cannot open container " + job.filename + "\n");
+				}
+			} else
+			{
+				job.root = open_canvas_as(FileSystemNative::instance()->get_identifier(job.filename), job.filename, errors, warnings);
+			}
 		}
 		catch(runtime_error& x)
 		{
@@ -484,28 +534,30 @@ Job OptionsProcessor::extract_job() throw (SynfigToolException&)
 
 		if(!job.canvas)
 		{
-			throw (SynfigToolException(SYNFIGTOOL_FILENOTFOUND,
-					strprintf(_("Unable to load '%s'."), job.filename.c_str())));
+		    throw SynfigToolException(SYNFIGTOOL_FILENOTFOUND,
+                                      (boost::format(_("Unable to load file '%s'.")) % job.filename).str());
 		}
 
 		job.root->set_time(0);
 	}
 	else
-		throw (SynfigToolException(SYNFIGTOOL_MISSINGARGUMENT,
-									_("No input file provided.")));
+	{
+	    throw SynfigToolException(SYNFIGTOOL_MISSINGARGUMENT,
+                                  _("No input file provided."));
+	}
 
 	if (_vm.count("target"))
 	{
-		job.target_name = _vm["target"].as<string>();
-		VERBOSE_OUT(1) << _("Target set to ") << job.target_name.c_str() << endl;
+		job.target_name = _vm["target"].as<std::string>();
+		VERBOSE_OUT(1) << _("Target set to ") << job.target_name << std::endl;
 	}
 
 	// Determine output
 	if (_vm.count("output-file"))
 	{
-		job.outfilename = _vm["output-file"].as<string>();
+		job.outfilename = _vm["output-file"].as<std::string>();
 	}
-	
+
 	if (_vm.count("extract-alpha"))
 	{
 		job.extract_alpha = true;
@@ -516,33 +568,35 @@ Job OptionsProcessor::extract_job() throw (SynfigToolException&)
 	else
 		job.quality = DEFAULT_QUALITY;
 
-	VERBOSE_OUT(1) << _("Quality set to ") << job.quality << endl;
+	VERBOSE_OUT(1) << _("Quality set to ") << job.quality << std::endl;
 
 	// WARNING: canvas must be before append
 
 	if (_vm.count("canvas"))
 	{
-		string canvasid;
-		canvasid = _vm["canvas"].as<string>();
+		std::string canvasid;
+		canvasid = _vm["canvas"].as<std::string>();
 
 		try
 		{
-			string warnings;
+			std::string warnings;
 			job.canvas = job.root->find_canvas(canvasid, warnings);
 			// TODO: This exceptions should not terminate the program if multi-job
 			// processing is available.
 		}
 		catch(Exception::IDNotFound&)
 		{
-			throw (SynfigToolException(SYNFIGTOOL_INVALIDJOB,
-					strprintf(_("Unable to find canvas with ID \"%s\" in %s.\n"
-								"Throwing out job..."), canvasid.c_str(), job.filename.c_str())));
+			throw SynfigToolException(SYNFIGTOOL_INVALIDJOB,
+                    (boost::format(_("Unable to find canvas with ID \"%s\" in %s.\n"
+                                     "Throwing out job..."))
+                                   % canvasid % job.filename).str());
 		}
 		catch(Exception::BadLinkName&)
 		{
-			throw (SynfigToolException(SYNFIGTOOL_INVALIDJOB,
-					strprintf(_("Invalid canvas name \"%s\" in %s.\n"
-								"Throwing out job..."), canvasid.c_str(), job.filename.c_str())));
+		    throw SynfigToolException(SYNFIGTOOL_INVALIDJOB,
+                    (boost::format(_("Invalid canvas name \"%s\" in %s.\n"
+                                     "Throwing out job..."))
+                                   % canvasid % job.filename).str());
 		}
 
 		// Later we need to set the other parameters for the jobs
@@ -553,11 +607,28 @@ Job OptionsProcessor::extract_job() throw (SynfigToolException&)
 	if (_vm.count("append"))
 	{
 		// TODO: Enable multi-appending. Disabled in the previous CLI version
-		string composite_file;
-		composite_file = _vm["append"].as<string>();
+		std::string composite_file = _vm["append"].as<std::string>();
+
+		std::string errors, warnings;
+		Canvas::Handle composite;
+		// todo: literals ".sfg", "container:", "project.sifz"
+		if (bfs::path(composite_file).extension() == ".sfg")
+		{
+			etl::handle< FileContainerZip > container = new FileContainerZip();
+			if (container->open(job.filename))
+			{
+				etl::handle< FileSystemGroup > file_system( new FileSystemGroup(FileSystemNative::instance()) );
+				file_system->register_system("#", container);
+				job.root = open_canvas_as(file_system->get_identifier("#project.sifz"), composite_file, errors, warnings);
+			} else
+			{
+				errors.append("Cannot open container " + composite_file + "\n");
+			}
+		} else
+		{
+			composite = open_canvas_as(FileSystemNative::instance()->get_identifier(composite_file), composite_file, errors, warnings);
+		}
 
-		string errors, warnings;
-		Canvas::Handle composite(open_canvas(composite_file, errors, warnings));
 		if(!composite)
 		{
 			VERBOSE_OUT(1) << _("Unable to append '") << composite_file.c_str()
@@ -574,10 +645,10 @@ Job OptionsProcessor::extract_job() throw (SynfigToolException&)
 			}
 		}
 
-		VERBOSE_OUT(2) << _("Appended contents of ") << composite_file.c_str() << endl;
+		VERBOSE_OUT(2) << _("Appended contents of ") << composite_file << endl;
 	}
-	/*=== This is a code that comes from bones branch 
-	      possibly it is the solution for multi-appending mentioned before ====	
+	/*=== This is a code that comes from bones branch
+	      possibly it is the solution for multi-appending mentioned before ====
 	// Extract composite
 	do{
 		string composite_file;
@@ -585,7 +656,7 @@ Job OptionsProcessor::extract_job() throw (SynfigToolException&)
 		if(!composite_file.empty())
 		{
 			String errors, warnings;
-			Canvas::Handle composite(open_canvas(composite_file, errors, warnings));
+			Canvas::Handle composite(open_canvas_as(FileSystemNative::instance()->get_identifier(composite_file), composite_file, errors, warnings));
 			if(!composite)
 			{
 				cerr<<_("Unable to append '")<<composite_file<<"'."<<endl;
@@ -601,16 +672,16 @@ Job OptionsProcessor::extract_job() throw (SynfigToolException&)
 			VERBOSE_OUT(2)<<_("Appended contents of ")<<composite_file<<endl;
 		}
 	} while(false);
-	
+
 	VERBOSE_OUT(4)<<_("Attempting to determine target/outfile...")<<endl;
 	>>>>>>> genete_bones
 	 */
 	if (_vm.count("list-canvases") || _vm.count("canvases"))
 	{
 		print_child_canvases(job.filename + "#", job.root);
-		cerr << endl;
+		std::cerr << std::endl;
 
-		throw (SynfigToolException(SYNFIGTOOL_OK));
+		throw SynfigToolException(SYNFIGTOOL_OK);
 	}
 
 	if (_vm.count("canvas-info"))
@@ -618,40 +689,50 @@ Job OptionsProcessor::extract_job() throw (SynfigToolException&)
 		extract_canvas_info(job);
 		print_canvas_info(job);
 
-		throw (SynfigToolException(SYNFIGTOOL_OK));
+		throw SynfigToolException(SYNFIGTOOL_OK);
 	}
 
 	return job;
 }
 
+void OptionsProcessor::print_target_video_codecs_help() const
+{
+	for (std::vector<VideoCodec>::const_iterator itr = _allowed_video_codecs.begin();
+		 itr != _allowed_video_codecs.end(); ++itr)
+	{
+		std::cout << " " << itr->name << ":   \t" << itr->description
+				  << std::endl;
+	}
+}
+
 #ifdef _DEBUG
 
 // DEBUG auxiliar functions
 void guid_test()
 {
-	cout << "GUID Test" << endl;
+	std::cout << "GUID Test" << std::endl;
 	for(int i = 20; i; i--)
-		cout << synfig::GUID().get_string() << ' '
-			 << synfig::GUID().get_string() << endl;
+		std::cout << synfig::GUID().get_string() << ' '
+				  << synfig::GUID().get_string() << std::endl;
 }
 
 void signal_test_func()
 {
-	cout << "**SIGNAL CALLED**" << endl;
+	std::cout << "**SIGNAL CALLED**" << std::endl;
 }
 
 void signal_test()
 {
 	sigc::signal<void> sig;
 	sigc::connection conn;
-	cout << "Signal Test" << endl;
+	std::cout << "Signal Test" << std::endl;
 	conn = sig.connect(sigc::ptr_fun(signal_test_func));
-	cout << "Next line should exclaim signal called." << endl;
+	std::cout << "Next line should exclaim signal called." << std::endl;
 	sig();
 	conn.disconnect();
-	cout << "Next line should NOT exclaim signal called." << endl;
+	std::cout << "Next line should NOT exclaim signal called." << std::endl;
 	sig();
-	cout << "done."<<endl;
+	std::cout << "done." << std::endl;
 }
 
 // DEBUG options ----------------------------------------------
